MIC-package: MIC: Analysis of Antimicrobial Minimum Inhibitory...

MIC-packageR Documentation

MIC: Analysis of Antimicrobial Minimum Inhibitory Concentration Data

Description

Analyse, plot, and tabulate antimicrobial minimum inhibitory concentration (MIC) data. Validate the results of an MIC experiment by comparing observed MIC values to a gold standard assay, in line with standards from the International Organization for Standardization (2021) https://www.iso.org/standard/79377.html.

Author(s)

Maintainer: Alessandro Gerada alessandro.gerada2@liverpool.ac.uk (ORCID) [copyright holder]

Authors:

See Also

Useful links:


MIC documentation built on July 21, 2026, 5:09 p.m.